@@ -1038,6 +1038,24 @@ append_extension_subject_key_identifier (GcrCertificateExtensionSubjectKeyIdenti
 	return section;
 }
 
+static GcrCertificateSection *
+append_extension_authority_key_identifier (GcrCertificateExtensionAuthorityKeyIdentifier *extension)
+{
+	GcrCertificateSection *section;
+	GBytes *keyid;
+	const void *keyid_data;
+	size_t keyid_len;
+	char *display;
+
+	section = _gcr_certificate_section_new (egg_oid_get_description (GCR_OID_AUTHORITY_KEY_IDENTIFIER), FALSE);
+	keyid = gcr_certificate_extension_authority_key_identifier_get_key_id (extension);
+	keyid_data = g_bytes_get_data (keyid, &keyid_len);
+	display = egg_hex_encode_full (keyid_data, keyid_len, TRUE, " ", 1);
+	_gcr_certificate_section_new_field_take_value (section, _("Key Identifier"), g_steal_pointer (&display));
+
+	return section;
+}
+
 static GcrCertificateSection *
 append_extension_key_usage (GcrCertificateExtensionKeyUsage *extension)
 {
@@ -1080,6 +1098,102 @@ append_extension_subject_alt_name (GcrCertificateExtensionSubjectAltName *extens
 	return section;
 }
 
+static GcrCertificateSection *
+append_extension_certificate_policies (GcrCertificateExtensionCertificatePolicies *extension)
+{
+	GcrCertificateSection *section;
+	unsigned int n_policies;
+
+	section = _gcr_certificate_section_new (_("Certificate Policies"), FALSE);
+
+	n_policies = g_list_model_get_n_items (G_LIST_MODEL (extension));
+	for (unsigned int i = 0; i < n_policies; i++) {
+		GcrCertificatePolicy *policy;
+		const char *name;
+
+		policy = gcr_certificate_extension_certificate_policies_get_policy (extension, i);
+		name = gcr_certificate_policy_get_name (policy);
+		_gcr_certificate_section_new_field (section, _("Policy"), name);
+	}
+
+	return section;
+}
+
+static GcrCertificateSection *
+append_extension_aia (GcrCertificateExtensionAuthorityInfoAccess *extension)
+{
+	GcrCertificateSection *section;
+	unsigned int n_descriptions;
+
+	section = _gcr_certificate_section_new (egg_oid_get_description (GCR_OID_AUTHORITY_INFO_ACCESS), FALSE);
+
+	n_descriptions = g_list_model_get_n_items (G_LIST_MODEL (extension));
+	for (unsigned int i = 0; i < n_descriptions; i++) {
+		GcrAccessDescription *description;
+		GcrGeneralName *location;
+		const char *location_val, *method;
+
+		description = g_list_model_get_item (G_LIST_MODEL (extension), i);
+
+		location = gcr_access_description_get_location (description);
+		location_val = gcr_general_name_get_value (location);
+		_gcr_certificate_section_new_field (section, _("Location"), location_val);
+
+		method = gcr_access_description_get_method_name (description);
+		_gcr_certificate_section_new_field (section, _("Access Method"), method);
+
+		g_object_unref (description);
+	}
+
+	return section;
+}
+
+static GcrCertificateSection *
+append_extension_cdp (GcrCertificateExtensionCrlDistributionPoints *extension)
+{
+	GcrCertificateSection *section;
+	GcrDistributionPoint *item;
+	unsigned int i = 0;
+
+	section = _gcr_certificate_section_new (_("CRL Distribution Points"), FALSE);
+
+	while ((item = g_list_model_get_item (G_LIST_MODEL (extension), i)) != NULL) {
+		GcrGeneralNames *full_name;
+
+		full_name = gcr_distribution_point_get_full_name (item);
+		if (full_name != NULL) {
+			unsigned int n_names;
+
+			n_names = g_list_model_get_n_items (G_LIST_MODEL (full_name));
+			for (unsigned int j = 0; j < n_names; j++) {
+				GcrGeneralName *name;
+				const char *name_val;
+
+				name = gcr_general_names_get_name (full_name, j);
+				name_val = gcr_general_name_get_value (name);
+				_gcr_certificate_section_new_field (section, _("Distribution Point"), name_val);
+			}
+		} else {
+			const char *part;
+
+			part = gcr_distribution_point_get_relative_name_part (item, "cn");
+			if (part != NULL)
+				_gcr_certificate_section_new_field (section, _("Distribution Point CN"), part);
+			part = gcr_distribution_point_get_relative_name_part (item, "ou");
+			if (part != NULL)
+				_gcr_certificate_section_new_field (section, _("Distribution Point OU"), part);
+			part = gcr_distribution_point_get_relative_name_part (item, "u");
+			if (part != NULL)
+				_gcr_certificate_section_new_field (section, _("Distribution Point U"), part);
+		}
+
+		g_object_unref (item);
+		i++;
+	}
+
+	return section;
+}
+
 static GcrCertificateSection *
 append_extension_hex (GQuark oid,
                       GBytes *value)
@@ -1117,10 +1231,18 @@ append_extension (GcrCertificate          *self,
 		section = append_extension_extended_key_usage (GCR_CERTIFICATE_EXTENSION_EXTENDED_KEY_USAGE (extension));
 	else if (oid == GCR_OID_SUBJECT_KEY_IDENTIFIER)
 		section = append_extension_subject_key_identifier (GCR_CERTIFICATE_EXTENSION_SUBJECT_KEY_IDENTIFIER (extension));
+	else if (oid == GCR_OID_AUTHORITY_KEY_IDENTIFIER)
+		section = append_extension_authority_key_identifier (GCR_CERTIFICATE_EXTENSION_AUTHORITY_KEY_IDENTIFIER (extension));
 	else if (oid == GCR_OID_KEY_USAGE)
 		section = append_extension_key_usage (GCR_CERTIFICATE_EXTENSION_KEY_USAGE (extension));
 	else if (oid == GCR_OID_SUBJECT_ALT_NAME)
 		section = append_extension_subject_alt_name (GCR_CERTIFICATE_EXTENSION_SUBJECT_ALT_NAME (extension));
+	else if (oid == GCR_OID_CERTIFICATE_POLICIES)
+		section = append_extension_certificate_policies (GCR_CERTIFICATE_EXTENSION_CERTIFICATE_POLICIES (extension));
+	else if (oid == GCR_OID_AUTHORITY_INFO_ACCESS)
+		section = append_extension_aia (GCR_CERTIFICATE_EXTENSION_AUTHORITY_INFO_ACCESS (extension));
+	else if (oid == GCR_OID_CRL_DISTRIBUTION_POINTS)
+		section = append_extension_cdp (GCR_CERTIFICATE_EXTENSION_CRL_DISTRIBUTION_POINTS (extension));
 
 	/* Otherwise the default raw display */
 	if (!section) {
